@@ -22,7 +22,8 @@ class AtlassianRestAPI(object):
     response = None
 
     def __init__(self, url, username=None, password=None, timeout=60, api_root='rest/api', api_version='latest',
-                 verify_ssl=True, session=None, oauth=None, cookies=None, advanced_mode=None, kerberos=None):
+                 verify_ssl=True, session=None, oauth=None, cookies=None, advanced_mode=None, kerberos=None,
+                 cloud=False):
         if ('atlassian.net' in url or 'jira.com' in url) \
                 and '/wiki' not in url \
                 and self.__class__.__name__ in 'Confluence':
@@ -36,6 +37,7 @@ class AtlassianRestAPI(object):
         self.api_version = api_version
         self.cookies = cookies
         self.advanced_mode = advanced_mode
+        self.cloud = cloud
         if session is None:
             self._session = requests.Session()
         else:
